@@ -13,7 +13,7 @@ use WWW::LogicBoxes::Contact::US;
 
 use Carp;
 
-our $VERSION = '1.8.0'; # VERSION
+our $VERSION = '1.9.0'; # VERSION
 # ABSTRACT: Abstract Factory For Construction of Contacts
 
 sub construct_from_response {
@@ -23,7 +23,8 @@ sub construct_from_response {
     if( $response->{type} eq 'CaContact' ) {
         return WWW::LogicBoxes::Contact::CA->construct_from_response( $response );
     }
-    elsif( grep { $_ eq 'domus' } @{ $response->{contacttype} } ) {
+    elsif( ( grep { $_ eq 'domus' } @{ $response->{contacttype} } )
+        && exists $response->{ApplicationPurpose} && exists $response->{NexusCategory} ) {
         return WWW::LogicBoxes::Contact::US->construct_from_response($response);
     }
     else {
